@@ -511,6 +511,68 @@ ArchSpec::GetArchitectureName () const
     return "unknown";
 }
 
+bool 
+ArchSpec::IsMIPS() const
+{
+    const llvm::Triple::ArchType machine = GetMachine();
+    if(machine == llvm::Triple::mips ||
+       machine == llvm::Triple::mipsel ||
+       machine == llvm::Triple::mips64 ||
+       machine == llvm::Triple::mips64el)
+       return true;
+    return false;
+}
+
+std::string
+ArchSpec::GetClangTargetCPU ()
+{
+    std::string cpu;
+    const llvm::Triple::ArchType machine = GetMachine();
+
+    if (machine == llvm::Triple::mips ||
+        machine == llvm::Triple::mipsel ||
+        machine == llvm::Triple::mips64 ||
+        machine == llvm::Triple::mips64el)
+    {
+        switch (m_core)
+        {
+        case ArchSpec::eCore_mips32:
+        case ArchSpec::eCore_mips32el:
+            cpu = "mips32"; break;
+        case ArchSpec::eCore_mips32r2:
+        case ArchSpec::eCore_mips32r2el:
+            cpu = "mips32r2"; break;
+        case ArchSpec::eCore_mips32r3:
+        case ArchSpec::eCore_mips32r3el:
+            cpu = "mips32r3"; break;
+        case ArchSpec::eCore_mips32r5:
+        case ArchSpec::eCore_mips32r5el:
+            cpu = "mips32r5"; break;
+        case ArchSpec::eCore_mips32r6:
+        case ArchSpec::eCore_mips32r6el:
+            cpu = "mips32r6"; break;
+        case ArchSpec::eCore_mips64:
+        case ArchSpec::eCore_mips64el:
+            cpu = "mips64"; break;
+        case ArchSpec::eCore_mips64r2:
+        case ArchSpec::eCore_mips64r2el:
+            cpu = "mips64r2"; break;
+        case ArchSpec::eCore_mips64r3:
+        case ArchSpec::eCore_mips64r3el:
+            cpu = "mips64r3"; break;
+        case ArchSpec::eCore_mips64r5:
+        case ArchSpec::eCore_mips64r5el:
+            cpu = "mips64r5"; break;
+        case ArchSpec::eCore_mips64r6:
+        case ArchSpec::eCore_mips64r6el:
+            cpu = "mips64r6"; break;
+        default:
+            break;
+        }
+    }
+    return cpu;
+}
+
 uint32_t
 ArchSpec::GetMachOCPUType () const
 {
@@ -1483,10 +1545,14 @@ ArchSpec::DumpTriple(Stream &s) const
     llvm::StringRef arch_str = triple.getArchName();
     llvm::StringRef vendor_str = triple.getVendorName();
     llvm::StringRef os_str = triple.getOSName();
+    llvm::StringRef environ_str = triple.getEnvironmentName();
 
     s.Printf("%s-%s-%s",
              arch_str.empty() ? "*" : arch_str.str().c_str(),
              vendor_str.empty() ? "*" : vendor_str.str().c_str(),
              os_str.empty() ? "*" : os_str.str().c_str()
              );
+
+    if (!environ_str.empty())
+        s.Printf("-%s", environ_str.str().c_str());
 }
