@@ -258,18 +258,3 @@ PlatformAndroidRemoteGDBServer::ConnectProcess(const char* connect_url,
                                                    target,
                                                    error);
 }
-
-size_t
-PlatformAndroidRemoteGDBServer::ConnectToWaitingProcesses(Debugger& debugger, Error& error)
-{
-    std::vector<std::string> connection_urls;
-    GetPendingGdbServerList(connection_urls);
-
-    for (size_t i = 0; i < connection_urls.size(); ++i)
-    {
-        ConnectProcess(connection_urls[i].c_str(), nullptr, debugger, nullptr, error);
-        if (error.Fail())
-            return i; // We already connected to i process succsessfully
-    }
-    return connection_urls.size();
-}
