@@ -482,11 +482,19 @@ DWARFDebugInfoEntry::GetDIENamesAndRanges
                 case DW_AT_ranges:
                     {
                         const DWARFDebugRanges* debug_ranges = dwarf2Data->DebugRanges();
-                        debug_ranges->FindRanges(form_value.Unsigned(), ranges);
-                        // All DW_AT_ranges are relative to the base address of the
-                        // compile unit. We add the compile unit base address to make
-                        // sure all the addresses are properly fixed up.
-                        ranges.Slide(cu->GetBaseAddress());
+                        if (debug_ranges)
+                        {
+                            debug_ranges->FindRanges(form_value.Unsigned(), ranges);
+                            // All DW_AT_ranges are relative to the base address of the
+                            // compile unit. We add the compile unit base address to make
+                            // sure all the addresses are properly fixed up.
+                            ranges.Slide(cu->GetBaseAddress());
+                        }
+                        else
+                        {
+                            cu->GetSymbolFileDWARF()->GetObjectFile()->GetModule()->ReportError ("{0x%8.8x}: DIE has DW_AT_ranges(0x%" PRIx64 ") attribute yet DWARF has no .debug_ranges, please file a bug and attach the file at the start of this error message",
+                                                                                                 m_offset, form_value.Unsigned());
+                        }
                     }
                     break;
 
