@@ -550,7 +550,11 @@ StackFrame::GetVariableList (bool get_file_globals)
             const bool can_create = true;
             const bool stop_if_child_block_is_inlined_function = true;
             m_variable_list_sp.reset(new VariableList());
-            frame_block->AppendBlockVariables(can_create, get_child_variables, stop_if_child_block_is_inlined_function, m_variable_list_sp.get());
+            frame_block->AppendBlockVariables(can_create,
+                                              get_child_variables,
+                                              stop_if_child_block_is_inlined_function,
+                                              [this](Variable* v) { return v->IsInScope(this); },
+                                              m_variable_list_sp.get());
         }
     }
     
@@ -594,6 +598,7 @@ StackFrame::GetInScopeVariableList (bool get_file_globals)
         m_sc.block->AppendVariables (can_create, 
                                      get_parent_variables,
                                      stop_if_block_is_inlined_function,
+                                     [this](Variable* v) { return v->IsInScope(this); },
                                      var_list_sp.get());
     }
                      
